% Wrapper for the TSC implementation
%
% Arguments
% Y:  Data matrix
% q:  TSC parameter
% gt: Vector containing the data labels
% L:  Nbr of subspaces
% p:  Projection dimension or projection matrix

function [missr, fde, tcalc] = TSCRP(Y, q, gt, L, p, useTSCb)

    narginchk(4,5);
    if nargin < 5, p = 0; end
    if nargin < 6, useTSCb = false; end
    
    if useTSCb
        TSCfunc = @TSCb;
    else
        TSCfunc = @TSC;
    end
    
    grp = 0;
    Z = 0;
    
    try
        tic

        if(sum(size(p)) > 2)
            Y = p*Y;
        elseif p > 0
            Phi = 1/sqrt(p)*randn(p, size(Y,1));
            Y = Phi*Y;
        end

        [grp,Z,~] = TSCfunc(Y,q,L);

        tcalc = toc;

        missr = Misclassification(grp,gt);

        fde = feature_detection_error_l1(Z,L);
        
    catch err
        fprintf(['ERROR: ' err.message '\n']);
        
        save(['TSCdebug' datestr(now,'ddmmyyyyHHMMSSFFF') '.mat'],'Z','Y','q','gt','L','p');
        
        tcalc = NaN;
        missr = NaN;
        fde = NaN;
    end
end

