% Generate a union of subspaces that intesect in a fraction int_rat of
% their dimensions and are orthogonal in all other dimensions
%
% Arguments
% ds:      vector of subspace dimensions (the first entry is assumed to be
%          the largest dimension
% n:       ambient dimension
% int_rat: fraction of intersection
% rho:     sampling density

function [Y, GT] = generate_intersection_data(n,ds,int_rat,rho)

    % Generate ground truth
    GT = [];

    for i = 1:length(ds)
        GT = [GT i*ones(1,ds(i)*rho)];
    end

    % Compute dimension of intesection for each subspace
    dints = ceil(int_rat*ds);

    dtot = ds(1) + sum(ds(2:end) - dints(2:end));

    bases = cell(length(ds),1);
    
    % Generate all basis vectors
    Utot = orth(randn(n,dtot));

    % Assign basis vectors to subspaces
    uidx = dints(1);
    for j = 1:length(ds)
        bases{j} = [Utot(:,1:dints(j)) Utot(:,(uidx+1):(uidx+ds(j)-dints(j)))];
        uidx = uidx + ds(j)-dints(j);
    end

    % Generate data
    Y = [];
    for k = 1:length(ds)
        A = normc(randn(ds(k),ds(k)*rho));
        Y = [Y bases{k}*A];
    end
end